@@ -1,13 +1,22 @@
 #!/usr/bin/python3.7
 
+import sys
+import struct
 import os
 import io
+import time
+import array
+import getopt
+import platform
+import operator
+import errno
 import types
 import numpy as np
 import exifread
 import ctypes
+import zlib
 
-from .dng import Tag, dngIFD, dngTag, DNG
+from .dng import Type, Tag, dngHeader, dngIFD, dngTag, DNG
 
 
 class BroadcomRawHeader(ctypes.Structure):
